{% extends "django_spellbook/bases/sidebar_left.html" %}
{% load spellbook_tags %}

{% block spellbook_md %}
    <div class="sb-directory-index">
        <h2 class="sb-text-2xl sb-mb-4 sb-font-bold sb-text-text">{{ directory_name }}</h2>
        {% include "django_spellbook/directory_index/listing.html" %}
    </div>
{% endblock %}
