<div class="sb-card sb-border sb-border-radius-lg sb-shadow-sm sb-transition sb-mb-3 sb-bg-light {% if kwargs.class %}{{ kwargs.class }}{% endif %}">
    {% if title %}
        <div class="sb-card-header sb-p-2 sb-bold">
            <h5 class="sb-card-title">{{ title }}</h5>
        </div>
    {% endif %}
    <div class="sb-card-body sb-p-3">
        {{ content|safe }}
    </div>
    {% if footer %}
        <div class="sb-card-footer sb-p-2">
            {{ footer }}
        </div>
    {% endif %}
</div>
